# -*- coding: utf-8 -*-
from django import template
from greeking import quotables
from django.utils.html import format_html
from greeking.fillmurray import get_url as get_fillmurray_url
from greeking.placeholdit import get_url as get_placeholdit_url
from greeking.placekittens import get_url as get_placekitten_url
from greeking.pangrams import get_pangram, get_html as get_pangram_html
from greeking.jabberwocky import get_grafs, get_html as get_jabberwocky_html
from greeking.latimes_ipsum import get_story, get_related_items, get_image, get_quote
register = template.Library()


@register.simple_tag
def latimes_story():
    """
    Return an latimes_ipsum Story object, which has many possible variables,
    including slug, headline, byline, pub_date, canonical_url, kicker, description,
    sources, credits, and image (which are used for header images and has a default size of 900).

    Example:

        {% latimes_story as obj %}
            {{ obj.headline }}
            {{ obj.byline }}
            {{ obj.caption }}

    """
    return get_story()


@register.simple_tag
def latimes_image(width, height, background_color):
    """
    Return an latimes_ipsum Image object with a default background color of #ccc unless you specify
    a background color. Also has option to return caption and credit.

    Usage format:

        {% latimes_image [width] [height] [background_color] as obj %}

    Example usage:

        Image at 250 wide and 400 high with background color of #000
        {% latimes_image 250 400 000000 %}
        <img src="{{obj.url}}">
        {{ obj.caption }}
        {{ obj.credit }}

    """
    return get_image(width, height, background_color)


@register.simple_tag
def latimes_quote():
    """
    Return an latimes_ipsum Quote object.

    Example:

        {% latimes_quote as obj %}
            {{ obj.quote }}
            {{ obj.source }}

    """
    return get_quote()


@register.simple_tag
def latimes_related_items(count=4):
    """
    Return a list of latimes_ipsum Quote object.

    Example usage:

    {% latimes_related_items as related_items %}
    {% for item in related_items %}
        <div>
                <a href="{{ item.url }}">
                   <p>{{ item.headline }}</p>
                </a>
                <a href="{{ item.url }}">
                   <img src="{{ item.image_url }}">
                </a>
        </div>
    {% endfor %}

    """
    return get_related_items(count)


@register.simple_tag
def fillmurray(width, height):
    """
    Creates a random image of Bill Murray at the provided width and height.

    Usage format:

        {% fillmurray [width] [height] %}

    Example usage:

        Color image at 250 wide and 400 high
        {% fillmurray 250 400 %}
    """
    url = get_fillmurray_url(width, height)
    return format_html('<img src="{}"/>', url)


@register.simple_tag
def placeholdit(
    width,
    height,
    background_color="cccccc",
    text_color="969696",
    text=None,
    random_background_color=False
):
    """
    Creates a placeholder image using placehold.it

    Usage format:

      {% placeholdit [width] [height] [background_color] [text_color] [text] %}

    Example usage:

        Default image at 250 square
        {% placeholdit 250 %}

        100 wide and 200 high
        {% placeholdit 100 200 %}

        Custom background and text colors
        {% placeholdit 100 200 background_color='fff' text_color=000' %}

        Custom text
        {% placeholdit 100 200 text='Hello LA' %}
    """
    url = get_placeholdit_url(
        width,
        height,
        background_color=background_color,
        text_color=text_color,
        text=text,
    )
    return format_html('<img src="{}"/>', url)


@register.simple_tag
def placekitten(width, height):
    """
    Creates an image of a random kitten at the provided width and height.

    Usage format:

        {% placekitten [width] [height] %}

    Example usage:

        Color image at 250 wide and 400 high
        {% placekitten 250 400 %}
    """
    url = get_placekitten_url(width, height)
    return format_html('<img src="{}"/>', url)


@register.simple_tag
def greek_comment_list():
    """
    Allows a template-level call of filler comments.

    Example usage:
    {% greek_comment_list as comment_list %}
    {% for comment in comment_list %}
        <div id="c{{ comment.id }}">
                <p>{{ comment.comment }}</p>
                <p>{{ comment.user_name }}</p>
                <p>{{ comment.submit_date|date:"F j, Y" }}</p>
                <p><a href="mailto:{{ comment.user_email }}">
                    {{ comment.user_email }}
                 </a></p>
                <p><a href="{{ comment.user_url }}">
                    {{ comment.user_url }}
                </a></p>
        </div>
    {% endfor %}
    """
    return quotables.get_comment_list()


@register.simple_tag
def pangram(language='en'):
    """
    Prints a pangram in the specified language.

    A pangram is a phrase that includes every letter of an alphabet.

    Default is English. For a full list of available languages,
        refer to pangrams.py

    Usage format::

        {% pangram [language] %}

    ``language`` is the two-letter abbreviation the desired language.

    Examples:
        * ``{% pangram %}`` will output the default English pangram.
        * ``{% pangram 'fr' %}`` will output a French pangram.
    """
    try:
        pangram = get_pangram(language)
    except KeyError:
        raise template.TemplateSyntaxError(
            "Could not find a pangram for %r abbreviation" % language
        )
    return get_pangram_html(pangram)


@register.simple_tag
def jabberwocky(count=7):
    """
    Prints paragraphs from Lewis Caroll's poem Jabberwocky for greeking
    in templates.

    Usage format::

        {% jabberwocky [count] %}

    ``count`` is a number (or variable) containing the number of paragraphs or
    words to generate (default is 7, which prints the entire poem).

    Examples:
        * ``{% jabberwocky %}`` will output the common "lorem ipsum" paragraph
        * ``{% jabberwocky 3 %}`` will output three paragraphs from the poem
    """
    return get_jabberwocky_html(get_grafs(count or 7))



# -*- coding: utf-8 -*-
"""
Utility for generating placeholder images from http://placehold.it/
"""
import random
URL = 'http://placehold.it/%(width)sx%(height)s/%(bcolor)s/%(tcolor)s/'


def _get_random_color():
    """
    Returns a random color hex value.
    """
    return '%02X%02X%02X' % (
        random.randint(0, 255),
        random.randint(0, 255),
        random.randint(0, 255)
    )


def get_url(
    width, height=None, background_color="cccccc",
    text_color="969696", text=None, random_background_color=False
):
    """
    Craft the URL for a placeholder image.

    You can customize the background color, text color and text using
    the optional keyword arguments

    If you want to use a random color pass in random_background_color as True.
    """
    if random_background_color:
        background_color = _get_random_color()

    # If height is not provided, presume it is will be a square
    if not height:
        height = width
    d = dict(
        width=width,
        height=height,
        bcolor=background_color,
        tcolor=text_color
    )
    url = URL % d
    if text:
        text = text.replace(" ", "+")
        url = url + "?text=" + text
    return url



# -*- coding: utf-8 -*-
"""
Utility functions for generating QuerySet object_lists that simulate data
from django.contrib.comments
"""
import time
import datetime


def get_comment_list():
    """
    Returns a list of dummy comments.
    """
    return [Quotable(comment_id=i, **d) for i, d in enumerate(HIPHOP)]


class Quotable:
    """
    A dummy comment for use as template filler.

    Based on the models in django.contrib.comments.models
    """
    def __init__(self, comment_id, user_name, user_email, user_url, comment,
                 submit_date):
        self.comment_id = comment_id
        self.user_name = user_name
        self.user_email = user_email
        self.user_url = user_url
        self.comment = comment
        self.submit_date = submit_date


def make_datetime(date_string):
    """Convert a string into a datetime object."""
    date_format = '%Y-%m-%d %H:%M'
    return datetime.datetime(*time.strptime(date_string, date_format)[0:5])


HIPHOP = [
    {
        'user_name': 'Chuck D',
        'user_email': 'chuck@publicenemy.com',
        'user_url': 'http://lyricwiki.org/Public_Enemy:Rebel_Without_A_Pause',
        'comment': "No matter what the name - we're all the same. Pieces in \
one big chess game. Yeah - the voice of power is in the house - go take a \
shower boy.",
        'submit_date': make_datetime('1988-06-26 00:01'),
    },
    {
        'user_name': 'Puff Daddy',
        'user_email': 'diddy@badboy.com',
        'user_url': 'http://www.seeklyrics.com/lyrics/Puff-Daddy/PE-2000.html',
        'comment': "A bona fide playa, now who got the flavor. A non stop, \
rhythm rock, poetry sayer. I'm the life saver, the New York mayor. Before \
you try me, you better say your prayers.",
        'submit_date': make_datetime('1999-12-31 23:59')
    },
    {
        'user_name': 'Rakim',
        'user_email': 'rakim@ericbforpresident.com',
        'user_url': 'http://www.lyricstime.com/eric-b-rakim-lyrics-of-fury-\
lyrics.html',
        'comment': "The scene of a crime every night at the show. The fiend \
of a rhyme on the mic that you know. It’s only one capable, breaks-the \
unbreakable, melodies-unmakable, pattern-unecscapable.",
        'submit_date': make_datetime('1998-07-25 00:01')
    },
    {
        'user_name': 'AZ',
        'user_email': 'az@brooklyn.com',
        'user_url': 'http://www.lyricsdepot.com/az/rather-unique.html',
        'comment': "So it's gonna take more than your astrologist to \
knowledge this. A physiologist couldn't even figure out the exoticness. \
Raps demolishing certified the way I style it. My wordplay blaze with the \
rays of ultraviolence.",
        'submit_date': make_datetime('1995-10-10 10:10')
    },
    {
        'user_name': 'Butterfly',
        'user_email': 'butterfly@9thwonder.org',
        'user_url': 'http://www.lyricstime.com/digable-planets-rebirth-of-\
slick-cool-like-dat-lyrics.html',
        'comment': "How was the buzz entire hip hop era? Was fresh and fat \
since they started sayin’ Audi. Cause funks made fat from right beneath my \
hoodie. The puba of the styles like Miles and shit. Like sixties funky worms \
with waves and perms. Just sendin’ chunky rhythms right down ya block. We be \
to rap what key be to lock.",
        'submit_date': make_datetime('1993-09-27 00:01')
    },
    {
        'user_name': 'Phife Dawg',
        'user_email': 'diggy@canikick.it',
        'user_url': 'http://www.lyricstime.com/a-tribe-called-quest-award-\
tour-lyrics.html',
        'comment': "Comin’ with more hits than the Braves and the Yankees. \
Livin’ mad phat like an oversized Bam-bi. The wackest crews try to dis, it \
makes me laugh. When my track record’s longer than a DC-20 aircraft. So next \
time that you think you want somethin’ here. Make somethin’ differ, take \
that garbage to St. Elsewhere.",
        'submit_date': make_datetime('1993-11-09 00:01')
    },
    {
        'user_name': 'Del',
        'user_email': 'funkee@sunnymeadowz.com',
        'user_url': 'http://www.lyricstime.com/del-the-funky-homosapien-\
sunny-meadowz-lyrics.html',
        'comment': "I sit and write scriptures by the old wishin’ well. \
Collect all my notes and sail a boat back to Berkeley. Tries fill my vibe \
’cause my style is rather earthly. Some say it's wack but I ain’t tryin’ \
to hear it. As long as what I do contains my soul and my spirit.",
        'submit_date': make_datetime('1991-10-22 00:01')
    },
    {
        'user_name': 'Notorious B.I.G.',
        'user_email': 'bee.eye.gee@brooklyn.com',
        'user_url': 'http://www.azlyrics.com/lyrics/notoriousbig/ilove\
thedough.html',
        'comment': "Now we buy homes in unfamiliar places. Tito smile \
everytime he see our faces.",
        'submit_date': make_datetime('1997-03-25 00:16')
    },
    {
        'user_name': 'Jay-Z',
        'user_email': 'jigga@brooklyn.com',
        'user_url': 'http://www.lyricsmode.com/lyrics/s/scarface/guess_whos_\
back_feat_jay_z_beanie_sigel.html',
        'comment': "Face it y'all, y'all n----- playin' basic ball. I'm on \
the block like I'm eight feet tall.",
        'submit_date': make_datetime('2002-08-06 05:00')
    },
    {
        'user_name': 'Skoob',
        'user_email': 'skoob@brooklyn.com',
        'user_url': 'http://www.musicsonglyrics.com/D/dasefxlyrics/dasefx\
realhiphoplyrics.htm',
        'comment': 'We the roughest dream team, reign Supreme like a Cutlass. \
Get duckets, the dough. Can\'t touch the flow.',
        'submit_date': make_datetime('1995-08-26 12:01')
    },
]



# -*- coding: utf-8 -*-
"""
Utility for generating placeholder Bill Murray images
"""
URL = 'http://www.fillmurray.com/%(width)s/%(height)s/'


def get_url(width, height, color=True):
    """
    Craft the URL for a placekitten image.

    By default they are in color. To retrieve a grayscale image, set
    the color kwarg to False.
    """
    d = dict(width=width, height=height)
    return URL % d



import six
from django.test import TestCase
from django.template import Template, Context, TemplateSyntaxError


class GreekingTemplateTagTests(TestCase):

    def render(self, t, **c):
        ctx = Context(c)
        out = Template(t).render(ctx)
        return ctx, out

    def testJabberwocky(self):
        """
        Tests the tag for pulling jabberwocky
        """
        from greeking.jabberwocky import get_grafs, get_html
        graph_range = list(range(1, 8))
        for graphs in graph_range:
            t = "{% load greeking_tags %}{% jabberwocky " + str(graphs) + " %}"
            ctx, out = self.render(t)
            match = get_html(get_grafs(graphs))
            self.assertEqual(out, match)
        self.render("{% load greeking_tags %}{% jabberwocky foobar %}")
        self.render("{% load greeking_tags %}{% jabberwocky %}")
        self.assertRaises(
            TemplateSyntaxError,
            self.render,
            "{% load greeking_tags %}{% jabberwocky foo bar %}"
        )

    def testPangrams(self):
        """
        Tests the tag for pulling pangrams
        """
        from greeking.pangrams import PANGRAMS
        languages = list(PANGRAMS.keys())
        for language in languages:
            t = "{% load greeking_tags %}{% pangram '" + language + "' %}"
            self.render(t)
        self.assertRaises(
            TemplateSyntaxError,
            self.render,
            "{% load greeking_tags %}{% pangram foobar %}"
        )
        self.assertRaises(
            TemplateSyntaxError,
            self.render,
            "{% load greeking_tags %}{% pangram en foobar %}"
        )
        self.render("{% load greeking_tags %}{% pangram %}")

    def testGreekComments(self):
        """
        Tests the tag for pulling greek comments
        """
        from greeking import quotables
        t = "{% load greeking_tags %}{% greek_comment_list as comment_list %}"
        ctx, out = self.render(t)
        for comment in list(ctx['comment_list']):
            comment_dict = {
                'user_name': comment.user_name,
                'user_email': comment.user_email,
                'user_url': comment.user_url,
                'comment': comment.comment,
                'submit_date': comment.submit_date
            }
            match = quotables.HIPHOP[comment.comment_id]
            for k, v in list(comment_dict.items()):
                self.assertEqual(v, match[k])

    def testFillMuray(self):
        """
        Tests the tag for pulling Bill Murray images.
        """
        t1 = "{% load greeking_tags %}{% fillmurray 200 200 %}"
        ctx, out = self.render(t1)
        self.assertEqual(
            out,
            '<img src="http://www.fillmurray.com/200/200/"/>'
        )
        self.assertRaises(
            TemplateSyntaxError,
            self.render,
            "{% load greeking_tags %}{% fillmurray foobar %}"
        )

    def testPlaceholdIt(self):
        """
        Tests the tag for pulling placehold.it images.
        """
        t1 = "{% load greeking_tags %}{% placeholdit 250 250 %}"
        ctx, out = self.render(t1)
        self.assertEqual(
            out, u'<img src="http://placehold.it/250x250/cccccc/969696/"/>'
        )
        t2 = "{% load greeking_tags %}{% placeholdit 100 200 %}"
        ctx, out = self.render(t2)
        self.assertEqual(
            out, u'<img src="http://placehold.it/100x200/cccccc/969696/"/>'
        )
        t3 = "{% load greeking_tags %}{% placeholdit 100 200 \
background_color='fff' text_color='000' %}"
        ctx, out = self.render(t3)
        self.assertEqual(
            out, u'<img src="http://placehold.it/100x200/fff/000/"/>'
        )
        t4 = "{% load greeking_tags %}{% placeholdit 100 200 \
text='Hello LA' %}"
        ctx, out = self.render(t4)
        self.assertEqual(
            out, u'<img src="http://placehold.it/100x200/cccccc/969696/\
?text=Hello+LA"/>'
        )
        t5 = "{% load greeking_tags %}{% placeholdit 100 200 'fff' \
'000' 'Hello LA' %}"
        ctx, out = self.render(t5)
        self.assertEqual(
            out,
            u'<img src="http://placehold.it/100x200/fff/000/?text=Hello+LA"/>'
        )
        self.assertRaises(
            TemplateSyntaxError,
            self.render,
            "{% load greeking_tags %}{% placeholdit foobar %}"
        )
        self.assertRaises(
            TemplateSyntaxError,
            self.render,
            "{% load greeking_tags %}{% placeholdit 200 200 b a b c d e%}"
        )
        from greeking import placeholdit
        url = placeholdit.get_url(250, random_background_color=True)
        t6 = url
        ctx, out = self.render(t6)
        self.assertNotEqual(
            out, u'<img src="http://placehold.it/250x250/cccccc/969696/"/>'
        )

    def testPlaceKittens(self):
        """
        Tests the tag for pulling placekitten images.
        """
        t1 = "{% load greeking_tags %}{% placekitten 200 200 %}"
        ctx, out = self.render(t1)
        self.assertEqual(out, u'<img src="http://placekitten.com/200/200/"/>')
        self.assertRaises(
            TemplateSyntaxError,
            self.render,
            "{% load greeking_tags %}{% placekitten foobar %}"
        )

    def testLatimesIpsum(self):
        from greeking import latimes_ipsum

        story = latimes_ipsum.get_story()
        self.assertTrue(isinstance(story, latimes_ipsum.Story))
        self.assertTrue(isinstance(story.content, six.string_types))

        related_items = latimes_ipsum.get_related_items()
        self.assertTrue(isinstance(related_items[0], latimes_ipsum.RelatedItem))
        self.assertTrue(len(related_items) == 4)
        self.assertTrue(len(latimes_ipsum.get_related_items(1)) == 1)

        image = latimes_ipsum.get_image(250)
        self.assertTrue(isinstance(image, latimes_ipsum.Image))
        t2 = latimes_ipsum.get_image(250, 250, True)
        ctx, out = self.render(t2)
        self.assertTrue(
            t2.url != 'http://placehold.it/250x250/cccccc/969696/'
        )
        t3 = latimes_ipsum.get_image(250)
        ctx, out = self.render(t3)
        self.assertTrue(
            t3.url == 'http://placehold.it/250x250/cccccc/969696/'
        )

        quote = latimes_ipsum.get_quote()
        self.assertTrue(isinstance(quote, latimes_ipsum.Quote))

        """
        Tests the tags for pulling story, image, related items, and quotes
        """

        t4 = "{% load greeking_tags %}{% latimes_story as obj %}"
        ctx, out = self.render(t4)

        t5 = "{% load greeking_tags %}{% latimes_image 250 250 000000 as obj %} \
        {{ obj.url }} \
        {{ obj.caption }} \
        {{ obj.credit }}"
        ctx, out = self.render(t5)

        t6 = "{% load greeking_tags %}{% latimes_quote as obj %} \
        {{ obj.quote }} \
        {{ obj.source }}"
        ctx, out = self.render(t6)

        t7 = "{% load greeking_tags %}{% latimes_related_items as obj %} \
        {{ obj.headline }} \
        {{ obj.url }} \
        {{ obj.image_url }}"
        ctx, out = self.render(t7)

        t8 = "{% load greeking_tags %}{% latimes_related_items 1 as obj %}"

        ctx, out = self.render(t8)



# -*- coding: utf-8 -*-
"""
Create objects from past Los Angeles Times stories for use as boilerplate.
"""
from __future__ import absolute_import
import six
from . import placeholdit
from datetime import datetime
from django.utils import lorem_ipsum

#
# Objects
#


class Story(object):
    """
    A boilerplate story.
    """
    def __init__(
        self,
        slug,
        headline,
        byline,
        pub_date,
        canonical_url,
        kicker,
        description,
        sources,
        credits,
        content,
        image,
    ):
        self.slug = slug
        self.headline = headline
        self.byline = byline
        self.pub_date = pub_date
        self.canonical_url = canonical_url
        self.kicker = kicker
        self.description = description
        self.sources = sources
        self.credits = credits
        self.content = content
        self.image = image


class RelatedItem(object):
    """
    A condensed reference to a story.
    """
    def __init__(self, headline, url, image):
        self.headline = headline
        self.url = url
        self.image = image


class Image(object):
    """
    An image.
    """
    def __init__(self, url, credit, caption):
        self.url = url
        self.credit = credit
        self.caption = caption


class Quote(object):
    """
    A quote.
    """
    def __init__(self, quote, source):
        self.quote = quote
        self.source = source

#
# Retrieval methods
#


def get_story():
    """
    Returns a boiler plate story as an object.
    """
    return Story(
        slug="la-data-latimes-ipsum",
        headline="This is not a headline",
        byline="This is not a byline",
        pub_date=datetime.now(),
        canonical_url="http://www.example.com/",
        kicker="This is not a kicker",
        description=lorem_ipsum.COMMON_P.split(".")[0],
        sources="This is not a source",
        credits="This is not a credit",
        content=six.text_type('\n\n'.join(lorem_ipsum.paragraphs(6))),
        image=get_image(900)
    )


def get_related_items(count=4):
    """
    Returns the requested number of boiler plate related items as a list.
    """
    defaults = dict(
        headline="This is not a headline",
        url="http://www.example.com/",
        image=get_image(400, 400)
    )
    return [RelatedItem(**defaults) for x in range(0, count)]


def get_image(width, height=None, background_color="cccccc", random_background_color=False):
    """
    Returns image with caption, credit, and random background color as requested.
    """
    return Image(
        url=placeholdit.get_url(
            width,
            height=height,
            background_color=background_color,
            random_background_color=random_background_color
        ),
        credit="This is not an image credit",
        caption="This is not a caption"
    )


def get_quote():
    """
    Returns quote and its source.
    """
    return Quote(
        quote="This is not a pull quote",
        source="This is not a quote source"
    )



from setuptools import setup
from distutils.core import Command


class TestCommand(Command):
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        from django.conf import settings
        settings.configure(
            DATABASES={
                'default': {
                    'NAME': 'test.db',
                    'TEST_NAME': 'test.db',
                    'ENGINE': 'django.db.backends.sqlite3'
                }
            },
            INSTALLED_APPS=(
                'django.contrib.auth',
                'django.contrib.contenttypes',
                'django.contrib.sessions',
                'django.contrib.staticfiles',
                'greeking',
            ),
            TEMPLATES=[
                {
                    'BACKEND': 'django.template.backends.django.DjangoTemplates',
                    'DIRS': [],
                    'APP_DIRS': False,
                    'OPTIONS': {},
                },
            ]
        )
        from django.core.management import call_command
        import django
        django.setup()
        call_command('test', 'greeking')


setup(
    name='greeking',
    version='2.2.0',
    description='Django template tools for printing filler, a \
    technique from the days of hot type known as greeking.',
    author='Los Angeles Times Data Desk',
    author_email='datadesk@latimes.com',
    url='http://django-greeking.readthedocs.io/',
    download_url='http://github.com/palewire/django-greeking.git',
    include_package_data=True,
    packages=(
        'greeking',
        'greeking.templatetags',
    ),
    license='MIT',
    keywords='greeking pangrams lorem ipsum quotables comments \
    text jabberwocky placekittens fillmurray filler',
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Framework :: Django',
        'Framework :: Django :: 1.9',
        'Framework :: Django :: 1.10',
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    install_requires=('six>=1.5.2',),
    cmdclass={'test': TestCommand}
)
